==> haskell-typed-process-0.2.13.0-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typed-process
version:              0.2.13.0
visibility:           public
id:                   typed-process-0.2.13.0-2RuYEiFbp78FbdaRVyp7wd
key:                  typed-process-0.2.13.0-2RuYEiFbp78FbdaRVyp7wd
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/typed-process
synopsis:             Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://github.com/fpco/typed-process#readme>

category:             System
abi:                  56275c64a68ea3b9793de35ab7fc7b73
exposed:              True
exposed-modules:      System.Process.Typed System.Process.Typed.Internal
hidden-modules:       Paths_typed_process
import-dirs:          /usr/lib/ghc-9.4.8/site-local/typed-process-0.2.13.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/typed-process-0.2.13.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/typed-process-0.2.13.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typed-process
hs-libraries:         HStyped-process-0.2.13.0-2RuYEiFbp78FbdaRVyp7wd
depends:
    async-2.2.5-I3c3jWJAJDg4b98EnH7ZrW base-4.17.2.1
    bytestring-0.11.5.3 process-1.6.18.0 stm-2.5.1.0 text-2.0.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-typed-process/html/typed-process.haddock

haddock-html:         /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-typed-process-0.2.13.0-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typed-process
version:              0.2.13.0
visibility:           public
id:                   typed-process-0.2.13.0-7DngoP5zxcs4zcvi8hLngG
key:                  typed-process-0.2.13.0-7DngoP5zxcs4zcvi8hLngG
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/typed-process
synopsis:             Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://github.com/fpco/typed-process#readme>

category:             System
abi:                  446be60490d322e11e50889ebf61fc39
exposed:              True
exposed-modules:      System.Process.Typed System.Process.Typed.Internal
hidden-modules:       Paths_typed_process
import-dirs:          /usr/lib/ghc-9.4.8/site-local/typed-process-0.2.13.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/typed-process-0.2.13.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/typed-process-0.2.13.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typed-process
hs-libraries:         HStyped-process-0.2.13.0-7DngoP5zxcs4zcvi8hLngG
depends:
    async-2.2.5-BbhpjNcetBn7sq4yuFYnd1 base-4.17.2.1
    bytestring-0.11.5.3 process-1.6.18.0 stm-2.5.1.0 text-2.0.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-typed-process/html/typed-process.haddock

haddock-html:         /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
